[−][src]Macro core_extensions::const_default
Gets the ConstDefault::DEFAULT associated constant for This.
Use this macro to avoid using the wrong DEFAULT associated cosntant,
eg: a DEFAULT associated constant in an inherent impl block with a
subset of the constraints that the ConstDefault impl has.