KeyStr

Struct KeyStr 

pub struct KeyStr<'a, T> {
    pub str: &'a str,
    pub key: T,
}
Available on crate feature slices only.
A pair of (string slice, key) returned by the RSplitWhile/ SplitWhile iterators.

Fields

str: &'a str

str_slice is a string slice for which all characters were mapped to key by a closure.

key: T

The value that all the chars in the string slice were mapped to.

Implementations

Source

impl<'a, T> KeyStr<'a, T>

pub fn into_pair(self) -> (T, &'a str)

Converts this into a key, string slice pair