pub struct KeyStr<'a, T> {
pub str: &'a str,
pub key: T,
}Available on crate feature
slices only.Expand description
A pair of (string slice, key) returned by the RSplitWhile/ SplitWhile iterators.
Fields
str: &'a strstr_slice is a string slice for which all characters were mapped to key by a closure.
key: TThe value that all the chars in the string slice were mapped to.
Implementations